SWDEV-549309 - Ensure that the kernel is issued to a stream that is ass… (#552)
* SWDEV-549309 - Ensure that the kernel is issued to a stream that is associated to the current device
* SWDEV-549309 - Ensure that the kernel is issued to a stream that is associated to the current device in atomic tests
* SWDEV-549309 - Added fix for Unit_hipMallocFromPoolAsync_Multidevice_Concurrent test
* SWDEV-549309 - Added fix for Unit_hipMemcpyPeerAsync_Positive_Default
* SWDEV-549309 - Added fix for Unit_hipStreamAttachMemAsync_Positive_AttachGlobal and Unit_hipGetProcAddress_GraphAPIs_AddMemsetMemcpyNodes
[ROCm/hip-tests commit: d21a95cea8]
This commit is contained in:
committed by
GitHub
parent
17d12dff14
commit
5283a114b2
@@ -109,6 +109,7 @@ TEST_CASE("test_svm_byte_granularity") {
|
||||
// get all the devices going simultaneously
|
||||
for(unsigned int d = 0; d < num_devices; d++) // device ids starting at 1.
|
||||
{
|
||||
HIP_CHECK(hipSetDevice(d));
|
||||
write_owned_locations<<<num_elements, 1, 0, streams[d]>>>(pA, num_devices_plus_host, d);
|
||||
HIP_CHECK(hipGetLastError());
|
||||
}
|
||||
@@ -125,6 +126,7 @@ TEST_CASE("test_svm_byte_granularity") {
|
||||
size_t adjusted_num_elements = num_elements - num_devices;
|
||||
for(unsigned int d = 0; d < num_devices; d++)
|
||||
{
|
||||
HIP_CHECK(hipSetDevice(d));
|
||||
sum_neighbor_locations<<<adjusted_num_elements, 1, 0, streams[d]>>>(pA, num_devices_plus_host,
|
||||
error_counts[d]);
|
||||
HIP_CHECK(hipGetLastError());
|
||||
|
||||
Reference in New Issue
Block a user